==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/history/translations/history_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>Pilih Tanggal</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="59"/>
        <source>History</source>
        <translation>Riwayat</translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>Plugin Riwayat Putar</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>Tentang Plugin Riwayat Putar</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>Plugin Riwayat Putar Qmmp</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>Plugin ini mengumpulkan informasi tentang trek-trek yang diputar</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>Pengaturan Plugin Riwayat Putar</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>Format judul:</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>Riwayat</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>Rentang Waktu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>Dari:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>Sampai:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>Minggu lalu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>Bulan lalu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>Jalankan</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>Waktu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>Lagu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>Distribusi</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>Hari</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>Cacah putar</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>Lagu Top</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>Artis Top</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>Genre Top</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="124"/>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="125"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="200"/>
        <source>MM-yyyy</source>
        <translation>MM-yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="201"/>
        <source>dd MMMM</source>
        <translation>dd MMMM</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/history/translations/history_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>DateInputDialog</name>
    <message>
        <location filename="../dateinputdialog.ui" line="14"/>
        <source>Select Date</source>
        <translation>Pilih Tanggal</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <location filename="../history.cpp" line="57"/>
        <source>History</source>
        <translation>Riwayat</translation>
    </message>
    <message>
        <location filename="../history.cpp" line="58"/>
        <source>Alt+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryFactory</name>
    <message>
        <location filename="../historyfactory.cpp" line="31"/>
        <source>Listening History Plugin</source>
        <translation>Plugin Riwayat Putar</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="51"/>
        <source>About Listening History Plugin</source>
        <translation>Tentang Plugin Riwayat Putar</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="52"/>
        <source>Qmmp Listening History Plugin</source>
        <translation>Plugin Riwayat Putar Qmmp</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="53"/>
        <source>This plugin collects information about listened tracks</source>
        <translation>Plugin ini mengumpulkan informasi tentang trek-trek yang diputar</translation>
    </message>
    <message>
        <location filename="../historyfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HistorySettingsDialog</name>
    <message>
        <location filename="../historysettingsdialog.ui" line="14"/>
        <source>Listening History Plugin Settings</source>
        <translation>Pengaturan Plugin Riwayat Putar</translation>
    </message>
    <message>
        <location filename="../historysettingsdialog.ui" line="31"/>
        <source>Title format:</source>
        <translation>Format judul:</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <location filename="../historywindow.ui" line="14"/>
        <location filename="../historywindow.ui" line="110"/>
        <source>History</source>
        <translation>Riwayat</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="29"/>
        <source>Time Range</source>
        <translation>Rentang Waktu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="35"/>
        <source>From:</source>
        <translation>Dari:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="52"/>
        <source>To:</source>
        <translation>Sampai:</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="69"/>
        <source>Last week</source>
        <translation>Minggu lalu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="76"/>
        <source>Last month</source>
        <translation>Bulan lalu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="83"/>
        <source>Execute</source>
        <translation>Jalankan</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="129"/>
        <source>Time</source>
        <translation>Waktu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="134"/>
        <location filename="../historywindow.ui" line="183"/>
        <source>Song</source>
        <translation>Lagu</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="143"/>
        <source>Distribution</source>
        <translation>Distribusi</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="156"/>
        <source>Day</source>
        <translation>Hari</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="161"/>
        <location filename="../historywindow.ui" line="188"/>
        <location filename="../historywindow.ui" line="215"/>
        <location filename="../historywindow.ui" line="242"/>
        <source>Play counts</source>
        <translation>Cacah putar</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="170"/>
        <source>Top Songs</source>
        <translation>Lagu Top</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="197"/>
        <source>Top Artists</source>
        <translation>Artis Top</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="210"/>
        <source>Artist</source>
        <translation>Artist</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="224"/>
        <source>Top Genres</source>
        <translation>Genre Top</translation>
    </message>
    <message>
        <location filename="../historywindow.ui" line="237"/>
        <source>Genre</source>
        <translation>Genre</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="128"/>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="129"/>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="196"/>
        <source>MM-yyyy</source>
        <translation>MM-yyyy</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="197"/>
        <source>dd MMMM</source>
        <translation>dd MMMM</translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="498"/>
        <source>Add to Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="499"/>
        <source>&amp;View Track Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../historywindow.cpp" line="501"/>
        <source>Remove from History</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
